# -*- coding: utf-8 -*-
# Copyright 2010 Richard Dymond (rjdymond@gmail.com)
#
# This file is part of Pyskool.
#
# Pyskool is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# Pyskool is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Pyskool. If not, see <http://www.gnu.org/licenses/>.

SITTING_ON_CHAIR = 'SITTING_ON_CHAIR'
SITTING_ON_FLOOR = 'SITTING_ON_FLOOR'
WALK0 = 'WALK0'
WALK1 = 'WALK1'
WALK2 = 'WALK2'
WALK3 = 'WALK3'
ARM_UP = 'ARM_UP'
KNOCKED_OVER = 'KNOCKED_OVER'
KNOCKED_OUT = 'KNOCKED_OUT'
HITTING0 = 'HITTING0'
HITTING1 = 'HITTING1'
CATAPULT0 = 'CATAPULT0'
CATAPULT1 = 'CATAPULT1'
WATERPISTOL = 'WATERPISTOL'
BENDING_OVER = 'BENDING_OVER'
FLY = 'FLY'
RUN = 'RUN'
SIT = 'SIT'
HOP1 = 'HOP1'
HOP2 = 'HOP2'
WATER0 = 'WATER0'
WATER1 = 'WATER1'
WATER2 = 'WATER2'
WATER3 = 'WATER3'
WATER4 = 'WATER4'
STINKBOMB = 'STINKBOMB'
DESK_EMPTY = 'DESK_EMPTY'
DESK_STINKBOMBS = 'DESK_STINKBOMBS'
DESK_WATER_PISTOL = 'DESK_WATER_PISTOL'
BIKE_ON_FLOOR = 'BIKE_ON_FLOOR'
BIKE_UPRIGHT = 'BIKE_UPRIGHT'
PLANT_GROWING = 'PLANT_GROWING'
PLANT_GROWN = 'PLANT_GROWN'
WATER_DROP = 'WATER_DROP'
SHERRY_DROP = 'SHERRY_DROP'
CONKER = 'CONKER'
RIDING_BIKE0 = 'RIDING_BIKE0'
RIDING_BIKE1 = 'RIDING_BIKE1'
KISSING_ERIC = 'KISSING_ERIC'
